@@ -14,7 +14,8 @@ our @ISA = qw(DynaLoader);
 # please make sure the sub-version does not increase above '099'
 # SQL_DRIVER_VER is formatted as dd.dd.dddd
 # for version 5.x please switch to 5.00(_00) version numbering
-our $VERSION = '4.033_03';
+# keep $VERSION in Bundle/DBD/mysql.pm in sync
+our $VERSION = '4.035_01';
 
 bootstrap DBD::mysql $VERSION;
 
@@ -1433,6 +1434,12 @@ important if you modify access privileges or create new users.
 
 =back
 
+=item ping
+
+This can be used to send a ping to the server.
+
+    $rc = $dbh->ping();
+
 =back
 
 
@@ -1726,10 +1733,14 @@ have impact on the I<max_length> attribute.
 
 =item mysql_insertid
 
-MySQL has the ability to choose unique key values automatically. If this
-happened, the new ID will be stored in this attribute. An alternative
-way for accessing this attribute is via $dbh->{'mysql_insertid'}.
-(Note we are using the $dbh in this case!)
+If the statement you executed performs an INSERT, and there is an AUTO_INCREMENT
+column in the table you inserted in, this attribute holds the value stored into
+the AUTO_INCREMENT column, if that value is automatically generated, by
+storing NULL or 0 or was specified as an explicit value.
+
+Typically, you'd access the value via $sth->{mysql_insertid}. The value can
+also be accessed via $dbh->{mysql_insertid} but this can easily
+produce incorrect results in case one database handle is shared.
 
 =item mysql_is_blob
 
